[Rt-commit] rt branch, 4.0/silence-test-warnings, updated. rt-4.0.8-183-g795b2e6

Alex Vandiver alexmv at bestpractical.com
Mon Nov 26 13:58:42 EST 2012


The branch, 4.0/silence-test-warnings has been updated
       via  795b2e6588e541067d20385039d326f2cad05c67 (commit)
      from  82f86c79896ca5fd7ed513ab5862e1926e67ca1f (commit)

Summary of changes:
 lib/RT.pm | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

- Log -----------------------------------------------------------------
commit 795b2e6588e541067d20385039d326f2cad05c67
Author: Alex Vandiver <alexmv at bestpractical.com>
Date:   Mon Nov 26 13:57:10 2012 -0500

    Also wrap ->err and ->crit to ->error and ->critical

diff --git a/lib/RT.pm b/lib/RT.pm
index 5d3f557..989e54e 100644
--- a/lib/RT.pm
+++ b/lib/RT.pm
@@ -312,11 +312,14 @@ sub InitLogging {
     InitSignalHandlers();
 }
 
-{   # Work around bug in Log::Dispatch < 2.30, wherein ->warn() does not
-    # usefully propagate out, unlike ->warning()
+{   # Work around bug in Log::Dispatch < 2.30, wherein the short forms
+    # of ->warn, ->err, and ->crit do not usefully propagate out, unlike
+    # ->warning, ->error, and ->critical
     package Log::Dispatch;
     no warnings 'redefine';
     sub warn { shift->warning(@_) }
+    sub err  { shift->error(@_) }
+    sub crit { shift->critical(@_) }
 }
 
 sub InitSignalHandlers {

-----------------------------------------------------------------------


More information about the Rt-commit mailing list